#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 xcffib
version:              1.6.2
visibility:           public
id:                   xcffib-1.6.2-DPzlXlhOUyxDsjY1AplNMN
key:                  xcffib-1.6.2-DPzlXlhOUyxDsjY1AplNMN
license:              Apache-2.0
maintainer:           Tycho Andersen <tycho@tycho.pizza>
author:               Tycho Andersen
homepage:             http://github.com/tych0/xcffib
synopsis:             A cffi-based python binding for X
description:          A cffi-based python binding for X, comparable to xpyb
category:             X11
abi:                  e94fb78d9b913a680abf6d5fb4afa9ad
exposed:              True
exposed-modules:
    Data.XCB.Python.AST Data.XCB.Python.Parse Data.XCB.Python.PyHelpers

import-dirs:          /usr/lib/ghc-9.6.6/site-local/xcffib-1.6.2
library-dirs:         /usr/lib/ghc-9.6.6/site-local/xcffib-1.6.2
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/xcffib-1.6.2
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-xcffib
hs-libraries:         HSxcffib-1.6.2-DPzlXlhOUyxDsjY1AplNMN
depends:
    attoparsec-0.14.4-HxFEqrzE4jlDGISwMuQFm7 base-4.18.2.1
    bytestring-0.11.5.3 containers-0.6.7
    either-5.0.3-JkOYlMFA21vDSVcoYpBsXz
    filemanip-0.3.6.3-LDIIIdG8U927lbtFkq5kg5 filepath-1.4.300.1
    mtl-2.3.1 pretty-1.1.3.6 split-0.2.5-3KQHz3VjCt4O3lCLzOFzl
    xcb-types-0.15.0-6z9EOxYPeI87mDQie0Oecz

haddock-interfaces:   /usr/share/doc/haskell-xcffib/html/xcffib.haddock
haddock-html:         /usr/share/doc/haskell-xcffib/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

